@@ -14,7 +14,7 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with Paramiko; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 
 """
 Some unit tests for ssh protocol message blocks.
@@ -48,18 +48,18 @@ class MessageTest(unittest.TestCase):
         msg = Message()
         msg.add_boolean(True)
         msg.add_boolean(False)
-        msg.add_byte(byte_chr(0xf3))
+        msg.add_byte(byte_chr(0xF3))
 
-        msg.add_bytes(zero_byte + byte_chr(0x3f))
+        msg.add_bytes(zero_byte + byte_chr(0x3F))
         msg.add_list(["huey", "dewey", "louie"])
         self.assertEqual(msg.asbytes(), self.__b)
 
         msg = Message()
         msg.add_int64(5)
-        msg.add_int64(0xf5e4d3c2b109)
+        msg.add_int64(0xF5E4D3C2B109)
         msg.add_mpint(17)
-        msg.add_mpint(0xf5e4d3c2b109)
-        msg.add_mpint(-0x65e4d3c2b109)
+        msg.add_mpint(0xF5E4D3C2B109)
+        msg.add_mpint(-0x65E4D3C2B109)
         self.assertEqual(msg.asbytes(), self.__c)
 
     def test_decode(self):
@@ -73,22 +73,22 @@ class MessageTest(unittest.TestCase):
         msg = Message(self.__b)
         self.assertEqual(msg.get_boolean(), True)
         self.assertEqual(msg.get_boolean(), False)
-        self.assertEqual(msg.get_byte(), byte_chr(0xf3))
-        self.assertEqual(msg.get_bytes(2), zero_byte + byte_chr(0x3f))
+        self.assertEqual(msg.get_byte(), byte_chr(0xF3))
+        self.assertEqual(msg.get_bytes(2), zero_byte + byte_chr(0x3F))
         self.assertEqual(msg.get_list(), ["huey", "dewey", "louie"])
 
         msg = Message(self.__c)
         self.assertEqual(msg.get_int64(), 5)
-        self.assertEqual(msg.get_int64(), 0xf5e4d3c2b109)
+        self.assertEqual(msg.get_int64(), 0xF5E4D3C2B109)
         self.assertEqual(msg.get_mpint(), 17)
-        self.assertEqual(msg.get_mpint(), 0xf5e4d3c2b109)
-        self.assertEqual(msg.get_mpint(), -0x65e4d3c2b109)
+        self.assertEqual(msg.get_mpint(), 0xF5E4D3C2B109)
+        self.assertEqual(msg.get_mpint(), -0x65E4D3C2B109)
 
     def test_add(self):
         msg = Message()
         msg.add(5)
         msg.add(0x1122334455)
-        msg.add(0xf00000000000000000)
+        msg.add(0xF00000000000000000)
         msg.add(True)
         msg.add("cat")
         msg.add(["a", "b"])
@@ -98,10 +98,16 @@ class MessageTest(unittest.TestCase):
         msg = Message(self.__d)
         self.assertEqual(msg.get_adaptive_int(), 5)
         self.assertEqual(msg.get_adaptive_int(), 0x1122334455)
-        self.assertEqual(msg.get_adaptive_int(), 0xf00000000000000000)
+        self.assertEqual(msg.get_adaptive_int(), 0xF00000000000000000)
         self.assertEqual(msg.get_so_far(), self.__d[:29])
         self.assertEqual(msg.get_remainder(), self.__d[29:])
         msg.rewind()
         self.assertEqual(msg.get_adaptive_int(), 5)
         self.assertEqual(msg.get_so_far(), self.__d[:4])
         self.assertEqual(msg.get_remainder(), self.__d[4:])
+
+    def test_bytes_str_and_repr(self):
+        msg = Message(self.__d)
+        assert str(msg) == f"paramiko.Message({self.__d!r})"
+        assert repr(msg) == str(msg)
+        assert bytes(msg) == msg.asbytes() == self.__d
